@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-PixelArray 第三方微服务客户端
+PixelArray 像素云盘客户端
 这个库包含了常用的开发工具和服务集成：
 - order: 订单管理模块和支付模块
 - product: 产品管理模块
@@ -11,7 +11,7 @@ PixelArray 第三方微服务客户端
 - unified_login: 统一登录模块
 """
 
-__version__ = "1.0.0"
+__version__ = "1.0.3"
 __author__ = "Lu qi"
 __email__ = "qi.lu@pixelarrayai.com"
 
